@@ -21,8 +21,8 @@ from sahara_tempest_plugin.tests.api import base as dp_base
 
 
 class JobBinaryTest(dp_base.BaseDataProcessingTest):
-    # Link to the API documentation is http://docs.openstack.org/developer/
-    # sahara/restapi/rest_api_v1.1_EDP.html#job-binaries
+    # Link to the API documentation is https://developer.openstack.org/
+    # api-ref/data-processing/#job-binaries
 
     @classmethod
     def resource_setup(cls):
@@ -31,8 +31,8 @@ class JobBinaryTest(dp_base.BaseDataProcessingTest):
             'url': 'swift://sahara-container.sahara/example.jar',
             'description': 'Test job binary',
             'extra': {
-                'user': cls.os.credentials.username,
-                'password': cls.os.credentials.password
+                'user': cls.os_primary.credentials.username,
+                'password': cls.os_primary.credentials.password
             }
         }
         # Create extra cls.swift_job_binary variable to use for comparison to
