@@ -21,8 +21,8 @@ from sahara_tempest_plugin.tests.api import base as dp_base
 
 
 class JobTest(dp_base.BaseDataProcessingTest):
-    # NOTE: Link to the API documentation: http://docs.openstack.org/developer/
-    # sahara/restapi/rest_api_v1.1_EDP.html#jobs
+    # NOTE: Link to the API documentation: https://developer.openstack.org/
+    # api-ref/data-processing/#jobs
 
     @classmethod
     def resource_setup(cls):
@@ -33,8 +33,8 @@ class JobTest(dp_base.BaseDataProcessingTest):
             'url': 'swift://sahara-container.sahara/example.jar',
             'description': 'Test job binary',
             'extra': {
-                'user': cls.os.credentials.username,
-                'password': cls.os.credentials.password
+                'user': cls.os_primary.credentials.username,
+                'password': cls.os_primary.credentials.password
             }
         }
         resp_body = cls.create_job_binary(**job_binary)
