@@ -364,7 +364,7 @@ class BaseTestCase(base.BaseTestCase):
     def _read_source_file(self, source):
         if not source:
             return None
-        with open(self._get_file_with_defaults(source)) as source_fd:
+        with open(self._get_file_with_defaults(source), 'rb') as source_fd:
             data = source_fd.read()
         return data
 
@@ -381,7 +381,7 @@ class BaseTestCase(base.BaseTestCase):
 
         def to_hex_present(string):
             return "".join(map(lambda x: hex(ord(x)).replace("0x", "\\x"),
-                               string))
+                               string.decode('utf-8')))
         if destination:
             return destination
 
@@ -522,11 +522,12 @@ class BaseTestCase(base.BaseTestCase):
         security_group = None
         proxy_exist = False
 
-        if self.network['type'] == 'neutron':
-            floating_ip_pool = self.neutron.get_network_id(
-                self.network['public_network'])
-        elif not self.network['auto_assignment_floating_ip']:
-            floating_ip_pool = self.network['public_network']
+        if self.network['public_network']:
+            if self.network['type'] == 'neutron':
+                floating_ip_pool = self.neutron.get_network_id(
+                    self.network['public_network'])
+            elif not self.network['auto_assignment_floating_ip']:
+                floating_ip_pool = self.network['public_network']
 
         node_groups = []
         for ng in self.testcase['node_group_templates']:
